@@ -23,8 +23,8 @@ md_convert <- function(x, frag = TRUE, disallow = TRUE) {
   if (!has_markdown()) {
     stop("Package 'markdown' needed for this function to work.")
   } else {
-    html <- markdown::mark_html(text = x, options = c(
-      if (frag) "-standalone", "-smart", "-tasklist"
+    html <- markdown::mark_html(text = x, template = !frag, options = c(
+      "-smart", "-tasklist"
     ))
     if (disallow) {
       md_disallow(html)
